## 0.14.2.1 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 0.14.2 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 0.14.1 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.14.0 (2022-02-05)

Add stubs for `chevron` package (#7139)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

